@@ -378,3 +378,28 @@ test_that("Normal OC 2-sample case works for n2=0, crohn-2", {
 
     expect_numeric(design_noprior_b(-20, -30), lower=0, upper=1, any.missing=FALSE)
 })
+
+test_that("Normal OC 2-sample avoids undefined behavior, example 1", {
+    skip_on_cran()
+
+    sigma_ref <- 3.2
+    map_ref <- mixnorm(c(0.51, -2.1, 0.39), c(0.42, -2.1, 0.995), c(0.06, -1.99, 2.32), sigma=sigma_ref)
+    prior_flat <- mixnorm(c(1, 0, 100), sigma=sigma_ref)
+    alpha <- 0.05
+    dec  <- decision2S(1-alpha, 0, lower.tail=FALSE)
+    n <- 58
+    k <- 2
+    design_map  <- oc2S(prior_flat, map_ref, n, n/k, dec)
+    design_map_2  <- oc2S(prior_flat, map_ref, n, n/k, dec)
+
+    x <- seq(-2.6, -1.6, by=0.1)
+    expect_numeric(design_map(x, x), lower=0, upper=1, any.missing=FALSE)
+    expect_numeric(design_map(-3, -4), lower=0, upper=1, any.missing=FALSE)
+    expect_numeric(design_map(-3, 4), lower=0, upper=1, any.missing=FALSE)
+    expect_numeric(design_map(-1.6, -1.6), lower=0, upper=1, any.missing=FALSE)
+
+    expect_numeric(design_map_2(-3, -4), lower=0, upper=1, any.missing=FALSE)
+    expect_numeric(design_map_2(-3, 4), lower=0, upper=1, any.missing=FALSE)
+    expect_numeric(design_map_2(-1.6, -1.6), lower=0, upper=1, any.missing=FALSE)
+    expect_numeric(design_map_2(x, x), lower=0, upper=1, any.missing=FALSE)
+})
